opendvp.qupath\_utils package
=============================

Submodules
----------

opendvp.qupath\_utils.adata\_to\_qupath\_detections module
----------------------------------------------------------

.. automodule:: opendvp.qupath_utils.adata_to_qupath_detections
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.qupath\_utils.adata\_to\_voronoi\_qupath\_detections module
-------------------------------------------------------------------

.. automodule:: opendvp.qupath_utils.adata_to_voronoi_qupath_detections
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.qupath\_utils.parse\_colors\_for\_qupath module
-------------------------------------------------------

.. automodule:: opendvp.qupath_utils.parse_colors_for_qupath
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.qupath\_utils.qupath\_geojson\_to\_sdata module
-------------------------------------------------------

.. automodule:: opendvp.qupath_utils.qupath_geojson_to_sdata
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.qupath\_utils.sdata\_to\_qupath\_detections module
----------------------------------------------------------

.. automodule:: opendvp.qupath_utils.sdata_to_qupath_detections
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.qupath\_utils.segmentation\_mask\_to\_qupath\_detections module
-----------------------------------------------------------------------

.. automodule:: opendvp.qupath_utils.segmentation_mask_to_qupath_detections
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: opendvp.qupath_utils
   :members:
   :show-inheritance:
   :undoc-members:
